import { Button, Space, Modal, FormInstance, Form, Select } from "antd";
import { inject, observer } from "mobx-react";
import type { ColumnsType } from "antd/es/table";
import BTable from "@/components/b_table";
import { useEffect, useState } from "react";
import { UserDataType } from "@/model/userModel";
import { Store } from "antd/lib/form/interface";
import SimpleForm from "@/components/form/simple_form";
import React from "react";
import baseHttp from "@/service/base";
import dayjs from "dayjs";
import { traningConfig } from "./traning_config";
import { FormType } from "@/components/form/interface";
import TraningUser from "./traningUser";
const { Option } = Select;

const Trainings = (props: Store) => {
  const { trainingStore, trainingCatStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [isModalOpenUser, setIsModalOpenUser] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [tagId, setId] = useState<Number | null>(null);
  const [stashList, setStash] = useState<any>(null); // 仓库列表
  const [userList, setUserList] = useState<Array<any>>([]);
  const columns: ColumnsType<UserDataType> = [
    { title: "任务标题", dataIndex: "title" },
    { title: "任务描述", dataIndex: "desc" },
    { title: "任务地点", dataIndex: "address" },
    { title: "任务开始时间", dataIndex: "start_time" },
    { title: "任务结束时间", dataIndex: "end_time" },
    { title: "任务积分设置", dataIndex: "score" },
    { title: "任务类别", dataIndex: "category_identity" },
    {
      title: "操作",
      dataIndex: "id",
      render: (any, record) => (
        <Space wrap>
          <Button
            type="dashed"
            size="small"
            onClick={() => {
              trainingStore.id = record?.identity;
              setIsModalOpenUser(true);
            }}
          >
            训练人员管理
          </Button>
          <Button
            type="dashed"
            size="small"
            onClick={() => {
              edit(record);
            }}
          >
            编辑
          </Button>
          <Button
            type="dashed"
            danger
            size="small"
            onClick={() => {
              dele(record);
            }}
          >
            删除
          </Button>
        </Space>
      ),
    },
  ];
  const dele = (record) => {
    trainingStore.deleteItem(record.identity);
  };
  const edit = (record) => {
    let data = {
      ...record,
      start_time: dayjs(record.start_time),
      end_time: dayjs(record.end_time),
    };
    setProjectConfig([
      ...traningConfig,
      {
        type: FormType.cehckboxGroup,
        label: "参与人员选择",
        name: "user_id",
        value: [],
        checkboxData: userList,
        rules: [{ required: true, message: "请选择参与人员!" }],
      },
    ]);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(data);
    setRecord(data);
    setId(record.id);
  };
  useEffect(() => {
    trainingStore.getlist();
  }, [trainingStore]);
  useEffect(() => {
    trainingCatStore.getlist().then(() => {
      setStash(trainingCatStore.list);
    });
    baseHttp.get("/user/list", null).then((res) => {
      let data = res.data?.record ?? [];
      data.forEach((item) => {
        item.label = item.account;
        item.value = item.identity;
      });
      setUserList(data ?? []);
    });
  }, [trainingCatStore]);

  const onFinish = (values: any) => {
    let data = {
      ...values,
      score: Number(values.score),
      count: Number(values.count),
    };
    if (!tagId) {
      trainingStore.add(data);
    } else {
      trainingStore.putItem(tagId, data);
    }
    setIsModalOpen(false);
  };

  // 任务发布handler
  const fabu = () => {
    setProjectConfig([
      ...traningConfig,
      {
        type: FormType.cehckboxGroup,
        label: "参与人员选择",
        name: "user_id",
        value: [],
        checkboxData: userList,
        rules: [{ required: true, message: "请选择参与人员!" }],
      },
    ]);
    setId(null);
    setIsModalOpen(true);
  };
  const onFinishFailed = () => {};
  // 用户选择回调
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Space direction="horizontal" size={"middle"}>
          <Button onClick={() => fabu()}>任务发布</Button>
        </Space>
        <BTable
          store={trainingStore}
          columns={columns}
          dataSource={trainingStore.list}
        />
        <Modal
          title={!tagId ? "任务发布" : "任务编辑"}
          width={800}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          onCancel={() => {
            setId(null);
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formName="card_basic"
            colProps={25}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          >
            <>
              <Form.Item
                key="category_identity"
                label="训练类别"
                name="category_identity"
                rules={[{ required: true, message: "请选择训练类别!" }]}
              >
                <Select placeholder="">
                  {stashList?.map((v: any) => {
                    return (
                      <Option key={v.identity} value={v.identity}>
                        {v.name}
                      </Option>
                    );
                  })}
                </Select>
              </Form.Item>
            </>
          </SimpleForm>
        </Modal>

        <Modal
          title="训练人员"
          width={1200}
          open={isModalOpenUser}
          footer={null}
          onCancel={() => {
            setIsModalOpenUser(false);
          }}
        >
          <TraningUser/>
        </Modal>
      </Space>
    </div>
  );
};

export default inject("trainingStore", "trainingCatStore")(observer(Trainings));
